import React from 'react';
import { Modal, Table } from 'antd';
import { useModel, useRequest } from 'umi';
import { useState } from 'react';
import styles from './SyncModal.less';
import ATooltip from '../Tooltip';
import { fetchApi } from '@/utils/request';
import { firstCharToLowerCase, handleRequest } from '@/utils/tool';
import { useCallback } from 'react';
import system from '@/services/system';

const columns = [
  {
    title: '文件夹名称',
    dataIndex: 'projName',
    width: 200,
    render: (text: string) => (
      <ATooltip title={text} placement="topLeft">
        {text}
      </ATooltip>
    ),
  },
  {
    title: '创建人',
    dataIndex: 'age',
    width: 88,
  },
  {
    title: '描述',
    dataIndex: 'notice',
    render: (text: string) => (
      <ATooltip title={text} placement="topLeft">
        {text}
      </ATooltip>
    ),
  },
];

interface DataType {
  key: React.Key;
  name: string;
  age: number;
  address: string;
}

export default function SyncModal() {
  const { initialState: { currentUser } = {} } = useModel('@@initialState');
  const [btnLoading, setBtnLoading] = useState(false);
  const [modalVisible, setModalVisible] = useState(true);
  const [selectedKeys, setSelectedKeys] = useState<string[]>([]);
  const { loading, data } = useRequest(async () => {
    return await fetchApi('project/queryProjectListByUserId', {
      userId: currentUser!.id,
    });
  });

  const onOk = useCallback(async () => {
    setBtnLoading(true);
    const res = await system.syncProjects(selectedKeys);
    setBtnLoading(false);
    handleRequest(res!).success(() => {
      setModalVisible(false);
    });
  }, [selectedKeys]);

  return (
    <Modal
      title="同步文件夹至工作空间"
      visible={modalVisible}
      wrapClassName={styles.syncModal}
      cancelText="取消"
      okText="确定"
      width={540}
      onCancel={() => setModalVisible(false)}
      okButtonProps={{
        disabled: selectedKeys.length === 0,
        loading: btnLoading,
      }}
      onOk={onOk}
    >
      <div className={styles.title}>
        选择「与我有关的文件夹」，并同步到「我的电脑/工作空间」中
      </div>
      <Table
        className={styles.table}
        rowKey="id"
        loading={loading}
        rowSelection={{
          type: 'checkbox',
          onChange: (
            selectedRowKeys: React.Key[],
            selectedRows: DataType[],
          ) => {
            console.log(
              `selectedRowKeys: ${selectedRowKeys}`,
              'selectedRows: ',
              selectedRows,
            );
            setSelectedKeys(selectedRowKeys as string[]);
          },
          // getCheckboxProps: (record: DataType) => ({
          //   disabled: record.name === 'Disabled User', // Column configuration not to be checked
          //   name: record.name,
          // }),
        }}
        pagination={false}
        columns={columns}
        dataSource={data || []}
        scroll={{ y: 200 }}
      />
    </Modal>
  );
}
