import React from 'react';
import { useState } from 'react';
import styles from './sync.less';
import syncingImg from './assets/syncing.png';
import syncSuccessImg from './assets/sync.success.png';
import syncErrorImg from './assets/sync.error.png';
import classNames from 'classnames';
import SyncModal from '@/components/SyncModal';
import { useSocketMessages } from '@/services/socket';
import FileStatus from '@/components/FileStatus';
import { useMemo } from 'react';
import { TaskStatus } from '@/services/API.helper';
import { DATA } from '@/services/API';

enum SyncType {
  Syncing = 'syncing',
  SyncSuccess = 'syncSuccess',
  SyncError = 'syncError',
}

const syncTypeList = [
  { type: SyncType.Syncing, label: '同步中', icon: syncingImg },
  { type: SyncType.SyncSuccess, label: '同步成功', icon: syncSuccessImg },
  { type: SyncType.SyncError, label: '同步异常', icon: syncErrorImg },
];

export default function SyncView() {
  const originList = useSocketMessages();
  const [type, setType] = useState<SyncType>(SyncType.Syncing);

  const [syncingList, succList, failList] = useMemo(() => {
    return originList.reduce(
      (arr, item) => {
        if (item.taskSyncStatus === TaskStatus.FINISH) {
          arr[1].push(item);
          return arr;
        } else if (item.taskSyncStatus === TaskStatus.FAILED) {
          arr[2].push(item);
          return arr;
        }
        arr[0].push(item);
        return arr;
      },
      [[], [], []] as [
        DATA.SocketFileMsg[],
        DATA.SocketFileMsg[],
        DATA.SocketFileMsg[],
      ],
    );
  }, [originList]);

  const mapSyncTypeToCount = useMemo(() => {
    return {
      [SyncType.Syncing]: syncingList.length,
      [SyncType.SyncSuccess]: succList.length,
      [SyncType.SyncError]: failList.length,
    };
  }, [syncingList, succList, failList]);

  const curretList = useMemo(() => {
    if (type === SyncType.SyncSuccess) return succList;
    if (type === SyncType.SyncError) return failList;
    return syncingList;
  }, [type, succList, failList, syncingList]);

  return (
    <div className={styles.sync}>
      <div className={styles.left}>
        <h4>
          <span>同步任务</span>
        </h4>
        {syncTypeList.map(({ type: iType, label, icon }) => (
          <div
            key={label}
            className={classNames(
              styles.tab,
              iType === type ? styles.active : '',
            )}
            onClick={() => setType(iType)}
          >
            <img className={styles.icon} src={icon} alt="" />
            <span className={styles.label}>{label}</span>
            <span className={styles.count}>
              {mapSyncTypeToCount[iType] > 99
                ? '99+'
                : mapSyncTypeToCount[iType] || ''}
            </span>
          </div>
        ))}
      </div>
      <div className={styles.right}>
        <div className={styles.date}>
          <div>2021年6月14日</div>
        </div>
        {curretList.map((data) => (
          <FileStatus key={data.taskId} className={styles.item} data={data} />
        ))}
      </div>
      <SyncModal />
    </div>
  );
}
